CopticCal class

The Coptic calendar.

Inheritance

Constructors

CopticCal()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMonLength(int month, int year) int
Return the number of days in month of the given year.
inherited
getNumMonths(int year) int
Return the number of months in the given year.
inherited
getType() String
Return the calendar type identifier (e.g. 'gregorian', 'islamic').
override
isLeapYear(int year) bool
Return true if year is a leap year in this calendar.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited