HebrewCal class

The Hebrew (Jewish) lunisolar calendar.

Implemented types

Constructors

HebrewCal()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMonLength(int month, int year) int
Return the number of days in month of the given year.
override
getNumMonths(int year) int
Return the number of months in the given year.
override
getType() String
Return the calendar type identifier (e.g. 'gregorian', 'islamic').
override
isLeapYear(int year) bool
Return true if year is a leap year in this calendar.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

daysInYear(int year) int
The total number of days in year.
elapsedDays(int year) int
The number of days elapsed from the Hebrew epoch to the start of year.
lastDayOfMonth(int month, int year) int
The last day number of month in year, or 0 for the 13th month in a non-leap year.
longHeshvan(int year) bool
Whether the month of Heshvan in year has 30 days (instead of 29).
longKislev(int year) bool
Whether the month of Kislev in year has 30 days (instead of 29).
newYear(int year) int
The Gregorian rata die of the first day of year (1 Tishri).
newYearsCorrection(int year, int elapsed) int
The postponement correction (0, 1, or 2 days) applied to the New Year of year to avoid forbidden weekday starts.