getWeekOfMonth method
The ordinal number of the week within the month.
Resolves the first day of the week from locale internally (via
ILibLocaleInfo.getFirstDayOfWeek), rather than taking a pre-resolved
value.
Implementation
@override
int getWeekOfMonth(String? locale) =>
_toCalendarDate().getWeekOfMonth(locale);