timezone property
String?
get
timezone
The IANA timezone id associated with this date, or null if none.
Implementation
String? get timezone;
The IANA timezone id associated with this date, or null if none.
String? get timezone;