isILibReady property
bool
get
isILibReady
Whether iLib has finished loading and is ready to use.
Implementation
bool get isILibReady => _iLibPrepared;
Whether iLib has finished loading and is ready to use.
bool get isILibReady => _iLibPrepared;