getRegionAlpha3 method
Return the region of this locale as an ISO-3166-alpha3 region code.
Implementation
String? getRegionAlpha3() {
return region != null ? regionAlpha2ToAlpha3(region) : null;
}
Return the region of this locale as an ISO-3166-alpha3 region code.
String? getRegionAlpha3() {
return region != null ? regionAlpha2ToAlpha3(region) : null;
}