isPseudo method
Return true if the current locale is the special pseudo locale.
Implementation
bool isPseudo() {
return pseudoLocales.contains(spec);
}
Return true if the current locale is the special pseudo locale.
bool isPseudo() {
return pseudoLocales.contains(spec);
}