getScript method
Return the script used for the current locale.
If the current locale explicitly defines a script, then this script is returned.
If not, then the default script for the locale is returned.
Implementation
String getScript() {
final String jscode1 = 'new LocaleInfo("$locale").getScript()';
final String result = ILibJS.instance.evaluate(jscode1).stringResult;
return result;
}