getLocale method
Return the locale that was used to construct this number formatter object.
Implementation
String getLocale() {
return _locale;
}
Return the locale that was used to construct this number formatter object.
String getLocale() {
return _locale;
}