getRoundingMode method
Returns the rounding mode set up in the constructor.
Implementation
String getRoundingMode() {
return _roundingMode;
}
Returns the rounding mode set up in the constructor.
String getRoundingMode() {
return _roundingMode;
}