getSignificantDigits method
Returns the significant digits set up in the constructor. -1 means not set.
Implementation
int getSignificantDigits() {
return _significantDigits ?? -1;
}
Returns the significant digits set up in the constructor. -1 means not set.
int getSignificantDigits() {
return _significantDigits ?? -1;
}