getStyle method
Return the style that was used to construct this number formatter object.
Implementation
String getStyle() {
return _style;
}
Return the style that was used to construct this number formatter object.
String getStyle() {
return _style;
}