isGroupingUsed method
Returns true if this formatter groups together digits in the integral portion of a number.
Implementation
bool isGroupingUsed() {
return _prigroupSize > 0 && _style != 'nogrouping';
}
Returns true if this formatter groups together digits in the integral portion of a number.
bool isGroupingUsed() {
return _prigroupSize > 0 && _style != 'nogrouping';
}