getNeedsIME method
Return true if this script typically requires an input method engine to enter its characters.
Implementation
bool getNeedsIME() {
return (_info?['ime'] as bool?) ?? false;
}
Return true if this script typically requires an input method engine to enter its characters.
bool getNeedsIME() {
return (_info?['ime'] as bool?) ?? false;
}