sampleYear property
The year whose Jan/Jun offsets are sampled to classify standard vs daylight.
Implementation
static int Function() sampleYear = () => DateTime.now().year;
The year whose Jan/Jun offsets are sampled to classify standard vs daylight.
static int Function() sampleYear = () => DateTime.now().year;