ILibCaseMapper class

A class that maps a string to upper or lower case in a locale-sensitive manner.

Constructors

ILibCaseMapper({String? locale, String? direction})
locale locale to use when loading the mapper direction "toupper" for upper-casing, or "tolower" for lower-casing. Default if not specified is "toupper".

Properties

hashCode int
The hash code for this object.
no setterinherited
locale ILibLocale
getter/setter pair
mapData Map<String, String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
up bool
getter/setter pair

Methods

getLocale() ILibLocale
Return the locale that this mapper was constructed with.
map(String? string) String?
Map a string to lower case in a locale-sensitive manner.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited