getTimeZone method
The timezone associated with this date as a string, or null if none.
Method form kept alongside the timezone getter for consistency with the other accessor methods like getCalendar.
Implementation
@override
String? getTimeZone() => timezone;