getWeekOfMonth abstract method
The ordinal number of the week within the month.
Resolves the first day of the week from locale internally (via
ILibLocaleInfo.getFirstDayOfWeek), rather than taking a pre-resolved
value.
Implementation
int getWeekOfMonth(String? locale);