ILibDateFmtOptions class

Options that configure an ILibDateFmt. Unspecified options fall back to the locale's defaults.

Constructors

ILibDateFmtOptions({String? locale, String? length, String? type, String? calendar, String? timezone, bool? useNative, String? date, String? time, String? clock, String? template, String? meridiems})

Properties

calendar String?
The calendar to format in (e.g. 'gregorian', 'islamic').
getter/setter pair
clock String?
Clock convention: '12' or '24' hour.
getter/setter pair
date String?
Which date components to include, as a string of d/m/y (e.g. 'dmy').
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
length String?
Approximate size of the formatted string: 'short', 'medium', 'long', or 'full'.
getter/setter pair
locale String?
BCP-47 locale string to format for.
getter/setter pair
meridiems String?
Style of meridiems (e.g. AM/PM) to use.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template String?
A fixed template string that overrides the locale's default format.
getter/setter pair
time String?
Which time components to include (e.g. 'ahm' for meridiem/hour/minute).
getter/setter pair
timezone String?
IANA timezone name to format times in.
getter/setter pair
type String?
The type of value to format: 'date', 'time', or 'datetime'.
getter/setter pair
useNative bool?
Whether to use native-script digits when formatting numbers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited