MeridiemsInfo class
One meridiem range (e.g. AM or PM): its localized name and the wall-clock
start/end times ('HH:MM') it covers.
Constructors
- MeridiemsInfo({String? name, String? start, String? end})
Properties
- end ↔ String?
-
The inclusive end of the range as
'HH:MM'.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The localized display name of this meridiem.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start ↔ String?
-
The inclusive start of the range as
'HH:MM'.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited