ILibDurationFmtOptions class
Options that configure an ILibDurationFmt. Unspecified options fall back to the locale's defaults.
Constructors
- ILibDurationFmtOptions({String? locale, String? length, String? style, bool? useNative})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- length ↔ String?
-
'short','medium','long', or'full'. Defaults to'short'.getter/setter pair - locale ↔ String?
-
BCP-47 locale string (e.g.
'en-US'). Defaults to system locale.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style ↔ String?
-
'text'or'clock'. Defaults to'text'.getter/setter pair - useNative ↔ bool?
-
Whether to use native script digits. Defaults to locale setting.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited