language the ISO 639 2-letter code for the language,
or a full locale spec in BCP-47 format, or another Locale instance to copy from
region the ISO 3166 2-letter code for the region
variant the name of the variant of this locale, if any
script the ISO 15924 code of the script for this locale, if any
Return the ISO-639 alpha3 equivalent language code
for the given ISO 639 alpha1 language code.
If the given alpha1 code is not found, this function returns its argument unchanged.
Return the ISO-3166 alpha3 equivalent region code
for the given ISO 3166 alpha2 region code.
If the given alpha2 code is not found, this function returns its argument unchanged.