ILibScriptInfo class

Constructors

ILibScriptInfo(String script)
script The ISO 15924 4-letter identifier for the script

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script String?
getter/setter pair

Methods

getCasing() bool
Return true if this script uses lower- and upper-case characters.
getCode() String?
Return the 4-letter ISO 15924 identifier associated with this script.
getCodeNumber() int?
Get the ISO 15924 code number associated with this script.
getLongCode() String?
Get the long identifier associated with this script.
getName() String?
Get the name of this script in English.
getNeedsIME() bool
Return true if this script typically requires an input method engine to enter its characters.
getScriptDirection() String
Return the usual direction that text in this script is written in.
Possible return values are "rtl" for right-to-left,
"ltr" for left-to-right, and "ttb" for top-to-bottom.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited